@@ -3,7 +3,7 @@
 
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -24,18 +24,15 @@
 #include "oxygenarrowstateengine.h"
 #include "oxygenbackgroundhintengine.h"
 #include "oxygenbaseengine.h"
-#include "oxygencomboengine.h"
 #include "oxygencomboboxengine.h"
 #include "oxygencomboboxentryengine.h"
 #include "oxygendialogengine.h"
-#include "oxygenflatwidgetengine.h"
 #include "oxygengroupboxengine.h"
 #include "oxygengroupboxlabelengine.h"
 #include "oxygenhook.h"
 #include "oxygenhoverengine.h"
 #include "oxygenmainwindowengine.h"
 #include "oxygenmenubarstateengine.h"
-#include "oxygenmenuitemengine.h"
 #include "oxygenmenustateengine.h"
 #include "oxygenpanedengine.h"
 #include "oxygenscrollbarengine.h"
@@ -96,10 +93,6 @@ namespace Oxygen
         bool innerShadowsEnabled( void ) const
         { return _innerShadowsEnabled; }
 
-        //! combo engine
-        ComboEngine& comboEngine( void ) const
-        { return *_comboEngine; }
-
         //! combobox engine
         ComboBoxEngine& comboBoxEngine( void ) const
         { return *_comboBoxEngine; }
@@ -112,10 +105,6 @@ namespace Oxygen
         DialogEngine& dialogEngine( void ) const
         { return *_dialogEngine; }
 
-        //! flat widget
-        FlatWidgetEngine& flatWidgetEngine( void ) const
-        { return *_flatWidgetEngine; }
-
         //! groupbox engine
         GroupBoxEngine& groupBoxEngine( void ) const
         { return *_groupBoxEngine; }
@@ -128,10 +117,6 @@ namespace Oxygen
         MainWindowEngine& mainWindowEngine( void ) const
         { return *_mainWindowEngine; }
 
-        //! menu item engine
-        MenuItemEngine& menuItemEngine( void ) const
-        { return *_menuItemEngine; }
-
         //! hover engine
         HoverEngine& hoverEngine( void ) const
         { return *_hoverEngine; }
@@ -217,6 +202,12 @@ namespace Oxygen
         //! combobox list size adjustment hook
         static gboolean sizeAllocationHook( GSignalInvocationHint*, guint, const GValue*, gpointer );
 
+        //! combobox entry size adjustment hook
+        static gboolean comboBoxEntryHook( GSignalInvocationHint*, guint, const GValue*, gpointer );
+
+        //! background hint setting hook
+        static gboolean backgroundHintHook( GSignalInvocationHint*, guint, const GValue*, gpointer );
+
         //! inner shadow composited mode enabling hook
         static gboolean innerShadowHook( GSignalInvocationHint*, guint, const GValue*, gpointer );
 
@@ -234,9 +225,6 @@ namespace Oxygen
         //! background hint engine
         BackgroundHintEngine* _backgroundHintEngine;
 
-        //! combobox engine
-        ComboEngine* _comboEngine;
-
         //! combobox engine
         ComboBoxEngine* _comboBoxEngine;
 
@@ -246,9 +234,6 @@ namespace Oxygen
         //! dialog engine
         DialogEngine* _dialogEngine;
 
-        //! flat widget
-        FlatWidgetEngine* _flatWidgetEngine;
-
         //! groupbox engine
         GroupBoxEngine* _groupBoxEngine;
 
@@ -261,9 +246,6 @@ namespace Oxygen
         //! main window engine
         MainWindowEngine* _mainWindowEngine;
 
-        //! menu item engine
-        MenuItemEngine* _menuItemEngine;
-
         //! paned engine
         PanedEngine* _panedEngine;
 
@@ -324,12 +306,17 @@ namespace Oxygen
         Hook _realizationHook;
 
         //! combobox hook
+        Hook _comboBoxEntryHook;
+
+        //! size allocation hook
         Hook _sizeAllocationHook;
 
+        //! background hint hook
+        Hook _backgroundHintHook;
+
         //! inner shadows hook
         Hook _innerShadowHook;
 
-
         //@}
 
         //! keep track of all registered widgets, and associated destroy callback
