@@ -38,7 +38,8 @@ namespace Oxygen
 
         //! constructor
         ComboBoxData( void ):
-            _target( 0L )
+            _target( 0L ),
+            _list( 0L )
         {}
 
         //! destructor
@@ -55,6 +56,10 @@ namespace Oxygen
         //!@name modifiers
         //@{
 
+        //! list
+        void setList( GtkWidget* widget )
+        { _list = widget; }
+
         //! assign button
         void setButton( GtkWidget* value );
 
@@ -78,6 +83,10 @@ namespace Oxygen
         //!@name accessors
         //@{
 
+        //! list
+        GtkWidget* list( void ) const
+        { return _list; }
+
         //! pressed
         bool pressed( void ) const
         { return _button._pressed; }
@@ -86,6 +95,10 @@ namespace Oxygen
         bool hasFocus( void ) const
         { return _button._focus; }
 
+        //! true if sensitive
+        bool isSensitive( void ) const
+        { return _button._widget && gtk_widget_is_sensitive( _button._widget ); }
+
         //! true if either button or entry has hover
         bool hovered( void ) const
         { return std::find_if( _hoverData.begin(), _hoverData.end(), HoveredFTor() ) != _hoverData.end(); }
@@ -119,15 +132,14 @@ namespace Oxygen
         //!@name callbacks
         //@{
 
-        static void childStyleChangeNotifyEvent( GtkWidget*, GtkStyle*, gpointer );
         static gboolean childDestroyNotifyEvent( GtkWidget*, gpointer );
         static void childToggledEvent( GtkWidget*, gpointer );
         static void childSizeAllocateEvent( GtkWidget*, GtkAllocation*, gpointer );
 
         static gboolean enterNotifyEvent( GtkWidget*, GdkEventCrossing*, gpointer );
         static gboolean leaveNotifyEvent( GtkWidget*, GdkEventCrossing*, gpointer );
-        static void stateChangeEvent( GtkWidget*, GtkStateType, gpointer );
-
+        static void stateChangeEvent( GtkWidget*, GtkStateFlags, gpointer );
+        static void styleUpdatedEvent( GtkWidget*, gpointer );
 
         //@}
 
@@ -136,8 +148,20 @@ namespace Oxygen
         //! target widget
         GtkWidget* _target;
 
+        //! drop-down list, if set
+        GtkWidget* _list;
+
+        //!@name signals
+        //@{
+
+        //! state change signal
         Signal _stateChangeId;
 
+        //! style updated
+        Signal _styleUpdatedId;
+
+        //@}
+
         // handle child registration
         class ChildData
         {
@@ -159,11 +183,8 @@ namespace Oxygen
             //! widget
             GtkWidget* _widget;
 
-            //!@name callback ids
-            //@{
+            //!callback id
             Signal _destroyId;
-            Signal _styleChangeId;
-            //@}
 
         };
 
