@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
 * Copyright (c) 2010 Ruslan Kabatsayev <b7.10110111@gmail.com>
 *
 * This  library is free  software; you can  redistribute it and/or
@@ -19,17 +19,15 @@
 * MA 02110-1301, USA.
 */
 
+#include <gtk/gtk.h>
 #include "oxygeninnershadowdata.h"
 #include "../oxygengtkutils.h"
 #include "../config.h"
 #include "../oxygencairocontext.h"
-#include "../oxygencairoutils.h"
 #include "oxygenanimations.h"
 #include "../oxygenstyle.h"
 #include "../oxygenmetrics.h"
-
-#include <gtk/gtk.h>
-#include <cstdlib>
+#include <stdlib.h>
 
 #include <cassert>
 #include <iostream>
@@ -47,8 +45,11 @@ namespace Oxygen
         // store target
         _target = widget;
 
-        if( gdk_display_supports_composite( gtk_widget_get_display( widget ) ) )
-        { _exposeId.connect( G_OBJECT(_target), "expose-event", G_CALLBACK( targetExposeEvent ), this, true ); }
+        if( gdk_display_supports_composite( gtk_widget_get_display( widget ) ) && G_OBJECT_TYPE_NAME(widget) != std::string("GtkPizza") )
+        {
+            _compositeEnabled = true;
+            _exposeId.connect( G_OBJECT(_target), "draw", G_CALLBACK( targetExposeEvent ), this, true );
+        }
 
         // check child
         GtkWidget* child( gtk_bin_get_child( GTK_BIN( widget ) ) );
@@ -67,10 +68,10 @@ namespace Oxygen
     }
 
     //_____________________________________________
-    void InnerShadowData::disconnect( GtkWidget* )
+    void InnerShadowData::disconnect( GtkWidget* widget )
     {
         _target = 0;
-        for( ChildDataMap::reverse_iterator iter = _childrenData.rbegin(); iter != _childrenData.rend(); ++iter )
+        for( ChildDataMap::iterator iter = _childrenData.begin(); iter != _childrenData.end(); ++iter )
         { iter->second.disconnect( iter->first ); }
 
         // disconnect signals
@@ -84,39 +85,36 @@ namespace Oxygen
     void InnerShadowData::registerChild( GtkWidget* widget )
     {
 
-        #if ENABLE_INNER_SHADOWS_HACK
+        #if GTK_CHECK_VERSION(2,22,0)
 
         // make sure widget is not already in map
-        if( _childrenData.find( widget ) != _childrenData.end() ) return;
-
-        if( gtk_scrolled_window_get_shadow_type( GTK_SCROLLED_WINDOW( _target ) ) != GTK_SHADOW_IN )
-        { return; }
-
-        #if OXYGEN_DEBUG
-        std::cerr
-            << "Oxygen::InnerShadowData::registerChild -"
-            << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
-            << std::endl;
-        #endif
-
-        GdkWindow* window(gtk_widget_get_window(widget));
-        if(
-
-            // check window
-            window &&
-            gdk_window_get_window_type( window ) == GDK_WINDOW_CHILD &&
-
-            // check compositing
-            gdk_display_supports_composite( gtk_widget_get_display( widget ) ) &&
-
-            // make sure widget is scrollable
-            GTK_WIDGET_GET_CLASS( widget )->set_scroll_adjustments_signal )
+        if( _childrenData.find( widget ) == _childrenData.end() )
         {
+
+            #if OXYGEN_DEBUG
+            std::cerr
+                << "Oxygen::InnerShadowData::registerChild -"
+                << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
+                << std::endl;
+            #endif
+
             ChildData data;
             data._unrealizeId.connect( G_OBJECT(widget), "unrealize", G_CALLBACK( childUnrealizeNotifyEvent ), this );
-            data._initiallyComposited = gdk_window_get_composited(window);
-            gdk_window_set_composited(window,TRUE);
+
+            GdkWindow* window(gtk_widget_get_window(widget));
+            if(
+
+                // check window
+                window &&
+                gdk_window_get_window_type( window ) == GDK_WINDOW_CHILD &&
+                gdk_display_supports_composite( gtk_widget_get_display( widget ) ) )
+            {
+                data.initiallyComposited=gdk_window_get_composited(window);
+                gdk_window_set_composited(window,TRUE);
+            }
+
             _childrenData.insert( std::make_pair( widget, data ) );
+
         }
 
         #endif
@@ -126,7 +124,6 @@ namespace Oxygen
     //________________________________________________________________________________
     void InnerShadowData::unregisterChild( GtkWidget* widget )
     {
-        #if ENABLE_INNER_SHADOWS_HACK
 
         ChildDataMap::iterator iter( _childrenData.find( widget ) );
         if( iter == _childrenData.end() ) return;
@@ -141,33 +138,26 @@ namespace Oxygen
         iter->second.disconnect( widget );
         _childrenData.erase( iter );
 
-        #endif
     }
 
     //________________________________________________________________________________
     void InnerShadowData::ChildData::disconnect( GtkWidget* widget )
     {
-        #if ENABLE_INNER_SHADOWS_HACK
+
+        #if OXYGEN_DEBUG
+        std::cerr
+            << "Oxygen::InnerShadowData::ChildData::disconnect -"
+            << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
+            << std::endl;
+        #endif
 
         // disconnect signals
         _unrealizeId.disconnect();
 
         // remove compositing flag
         GdkWindow* window( gtk_widget_get_window( widget ) );
-
-        #if OXYGEN_DEBUG
-        std::cerr
-            << "Oxygen::InnerShadowData::ChildData::disconnect -"
-            << " widget: " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
-            << " window: " << window
-            << std::endl;
-        #endif
-
-        // restore compositing if different from initial state
-        if( GDK_IS_WINDOW( window ) && !gdk_window_is_destroyed(window) && gdk_window_get_composited( window ) != _initiallyComposited )
-        { gdk_window_set_composited( window, _initiallyComposited ); }
-
-        #endif
+        if( GTK_IS_WINDOW( window ) && G_OBJECT_TYPE_NAME( widget ) != std::string("GtkPizza") )
+        { gdk_window_set_composited(window,initiallyComposited); }
     }
 
     //____________________________________________________________________________________________
@@ -187,16 +177,15 @@ namespace Oxygen
     gboolean InnerShadowData::targetExposeEvent( GtkWidget* widget, GdkEventExpose* event, gpointer )
     {
 
-        #if ENABLE_INNER_SHADOWS_HACK
+        #if GTK_CHECK_VERSION(2,24,0)
         GtkWidget* child=gtk_bin_get_child(GTK_BIN(widget));
         GdkWindow* window=gtk_widget_get_window(child);
 
         #if OXYGEN_DEBUG
         std::cerr << "Oxygen::InnerShadowData::targetExposeEvent -"
             << " widget: " << widget << " (" << G_OBJECT_TYPE_NAME(widget) << ")"
-            << " child: " << child << " (" << G_OBJECT_TYPE_NAME(child) << ")"
+            << " child: " << child << " (" << G_OBJECT_TYPE_NAME(widget) << ")"
             << " path: " << Gtk::gtk_widget_path( child )
-            << " area: " << event->area
             << std::endl;
         #endif
 
@@ -213,15 +202,11 @@ namespace Oxygen
 
         // get window geometry
         GtkAllocation allocation( Gtk::gdk_rectangle() );
-        gdk_window_get_geometry( window, &allocation.x, &allocation.y, &allocation.width, &allocation.height, 0L );
+        gdk_window_get_geometry( window, &allocation.x, &allocation.y, &allocation.width, &allocation.height );
 
         // create context with clipping
         Cairo::Context context(gtk_widget_get_window(widget), &allocation );
 
-        // add event region
-        gdk_cairo_region(context,event->region);
-        cairo_clip(context);
-
         // draw child
         gdk_cairo_set_source_window( context, window, allocation.x, allocation.y );
         cairo_paint(context);
@@ -236,40 +221,6 @@ namespace Oxygen
         cairo_fill(context);
         #endif
 
-        // Render rounded combobox list child
-        if(Gtk::gtk_combobox_is_tree_view( child ))
-        {
-            StyleOptions options(widget,gtk_widget_get_state(widget));
-            Corners corners(CornersAll);
-            if(gtk_widget_get_visible(gtk_scrolled_window_get_vscrollbar(GTK_SCROLLED_WINDOW(widget))))
-            {
-                if(Gtk::gtk_widget_layout_is_reversed( widget ))
-                    corners &= ~CornersLeft;
-                else
-                    corners &= ~CornersRight;
-            }
-            if(gtk_widget_get_visible(gtk_scrolled_window_get_hscrollbar(GTK_SCROLLED_WINDOW(widget))))
-                corners &= ~CornersBottom;
-
-            int x(allocation.x),y(allocation.y),w(allocation.width),h(allocation.height);
-            cairo_rectangle(context,x,y,w,h);
-            if(!Gtk::gdk_default_screen_is_composited())
-            {
-                // Take ugly shadow into account
-                x+=1;
-                y+=1;
-                w-=2;
-                h-=2;
-            }
-            cairo_rounded_rectangle_negative(context,x,y,w,h,2,corners);
-            cairo_clip(context);
-
-            Style::instance().renderMenuBackground( gtk_widget_get_window(widget), context, allocation.x,allocation.y,allocation.width,allocation.height, options );
-
-            // Event handling finished, now let the event propagate
-            return FALSE;
-        }
-
         // draw the shadow
         /*
         TODO: here child widget's allocation is used instead of window geometry.
@@ -279,7 +230,7 @@ namespace Oxygen
         int basicOffset=2;
 
         // we only draw SHADOW_IN here
-        if( gtk_scrolled_window_get_shadow_type( GTK_SCROLLED_WINDOW( widget ) ) != GTK_SHADOW_IN )
+        if(gtk_scrolled_window_get_shadow_type(GTK_SCROLLED_WINDOW(widget)) != GTK_SHADOW_IN )
         {
             if( GTK_IS_VIEWPORT(child) && gtk_viewport_get_shadow_type(GTK_VIEWPORT(child)) == GTK_SHADOW_IN )
             {
@@ -351,22 +302,18 @@ namespace Oxygen
         int offsetX=basicOffset+Entry_SideMargin;
         int offsetY=basicOffset;
 
-        // clipRect
-        GdkRectangle clipRect( allocation );
-
         // hole background
-        Style::instance().renderHoleBackground(
-            gtk_widget_get_window(widget), widget, &clipRect,
+        Style::instance().renderHoleBackground( context,
+            gtk_widget_get_window(widget), widget,
             allocation.x-offsetX, allocation.y-offsetY, allocation.width+offsetX*2, allocation.height+offsetY*2 );
 
         // adjust offset and render hole
         offsetX -= Entry_SideMargin;
-        Style::instance().renderHole(
-            gtk_widget_get_window(widget), &clipRect,
+        Style::instance().renderHole( context,
             allocation.x-offsetX, allocation.y-offsetY, allocation.width+offsetX*2, allocation.height+offsetY*2,
             options, data );
 
-        #endif // enable inner shadows hack
+        #endif // Gtk version
 
         // let the event propagate
         return FALSE;
