@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
 * Copyright (c) 2010 Ruslan Kabatsayev <b7.10110111@gmail.com>
 *
 * MenuBarState prelight effect is based on
@@ -29,7 +29,6 @@
 
 #include "oxygenmenubarstatedata.h"
 #include "../oxygengtkutils.h"
-#include "../config.h"
 
 #include <gtk/gtk.h>
 
@@ -40,13 +39,6 @@ namespace Oxygen
     void MenuBarStateData::connect( GtkWidget* widget )
     {
 
-        #if OXYGEN_DEBUG
-        std::cerr
-            << "Oxygen::MenuBarStateData::connect - "
-            << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
-            << std::endl;
-        #endif
-
         _target = widget;
         _motionId.connect( G_OBJECT(widget), "motion-notify-event", G_CALLBACK( motionNotifyEvent ), this );
         _leaveId.connect( G_OBJECT(widget), "leave-notify-event", G_CALLBACK( leaveNotifyEvent ), this );
@@ -65,16 +57,9 @@ namespace Oxygen
     }
 
     //________________________________________________________________________________
-    void MenuBarStateData::disconnect( GtkWidget* )
+    void MenuBarStateData::disconnect( GtkWidget* widget )
     {
 
-        #if OXYGEN_DEBUG
-        std::cerr
-            << "Oxygen::MenuBarStateData::disconnect - "
-            << " " << _target << " (" << (_target ? G_OBJECT_TYPE_NAME( _target ) : "0x0") << ")"
-            << std::endl;
-        #endif
-
         _target = 0L;
 
         // disconnect signal
@@ -85,72 +70,10 @@ namespace Oxygen
         _current._timeLine.disconnect();
         _previous._timeLine.disconnect();
 
-        // disconnect all children
-        for( ChildrenMap::iterator iter = _children.begin(); iter != _children.end(); ++iter )
-        { iter->second.disconnect(); }
-
-        _children.clear();
-
         FollowMouseData::disconnect();
 
     }
 
-
-    //________________________________________________________________________________
-    void MenuBarStateData::registerChild( GtkWidget* widget )
-    {
-        if( widget && _children.find( widget ) == _children.end() )
-        {
-
-            #if OXYGEN_DEBUG
-            std::cerr
-                << "Oxygen::MenuBarStateData::registerChild -"
-                << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
-                << std::endl;
-            #endif
-
-            Signal destroyId;
-            destroyId.connect( G_OBJECT( widget ), "destroy", G_CALLBACK( childDestroyNotifyEvent ), this );
-            _children.insert( std::make_pair( widget, destroyId ) );
-        }
-
-    }
-
-    //________________________________________________________________________________
-    void MenuBarStateData::unregisterChild( GtkWidget* widget )
-    {
-
-        #if OXYGEN_DEBUG
-        std::cerr
-            << "Oxygen::MenuBarStateData::unregisterChild -"
-            << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
-            << std::endl;
-        #endif
-
-        ChildrenMap::iterator iter( _children.find( widget ) );
-
-        // erase from children map
-        if( iter != _children.end() )
-        {
-            iter->second.disconnect();
-            _children.erase( iter );
-        }
-
-        // reset corresponding data, if matches
-        if( widget == _previous._widget )
-        {
-            _previous._widget = 0L;
-            _previous._timeLine.disconnect();
-        }
-
-        if( widget == _current._widget )
-        {
-            _current._widget = 0L;
-            _current._timeLine.disconnect();
-        }
-
-    }
-
     //________________________________________________________________________________
     void MenuBarStateData::updateItems( GdkEventType type )
     {
@@ -159,8 +82,11 @@ namespace Oxygen
 
         const bool isLeaveEvent( type == GDK_LEAVE_NOTIFY );
 
-        gint xPointer, yPointer;
-        gdk_window_get_pointer( gtk_widget_get_window( _target ), &xPointer, &yPointer, 0L );
+        gint xPointer(0), yPointer(0);
+
+        GdkDeviceManager* manager( gdk_display_get_device_manager( gtk_widget_get_display( _target ) ) );
+        GdkDevice* pointer( gdk_device_manager_get_client_pointer( manager ) );
+        gdk_window_get_device_position( gtk_widget_get_window( _target ), pointer, &xPointer, &yPointer, 0L);
 
         bool activeFound( false );
         GtkWidget *activeWidget( 0L );
@@ -171,7 +97,6 @@ namespace Oxygen
             if( !( child->data && GTK_IS_MENU_ITEM( child->data ) ) ) continue;
 
             GtkWidget* childWidget( GTK_WIDGET( child->data ) );
-            registerChild( childWidget );
             const GtkStateType state( gtk_widget_get_state( childWidget ) );
 
             // do nothing for disabled child
@@ -224,9 +149,9 @@ namespace Oxygen
         if( !topLevel ) return false;
 
         return
-            GTK_WIDGET_VISIBLE( menu ) &&
-            GTK_WIDGET_REALIZED( topLevel ) &&
-            GTK_WIDGET_VISIBLE( topLevel );
+            gtk_widget_get_visible( menu ) &&
+            gtk_widget_get_realized( topLevel ) &&
+            gtk_widget_get_visible( topLevel );
     }
 
     //________________________________________________________________________________
@@ -314,19 +239,6 @@ namespace Oxygen
 
     }
 
-    //____________________________________________________________________________________________
-    gboolean MenuBarStateData::childDestroyNotifyEvent( GtkWidget* widget, gpointer data )
-    {
-        #if OXYGEN_DEBUG
-        std::cerr
-            << "Oxygen::MenuBarStateData::childDestroyNotifyEvent -"
-            << " " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")"
-            << std::endl;
-        #endif
-        static_cast<MenuBarStateData*>(data)->unregisterChild( widget );
-        return FALSE;
-    }
-
     //________________________________________________________________________________
     gboolean MenuBarStateData::motionNotifyEvent(GtkWidget*, GdkEventMotion*, gpointer pointer )
     {
