@@ -39,10 +39,7 @@ namespace Oxygen
 
         //! destructor
         virtual ~PanedData( void )
-        {
-            disconnect( 0L );
-            if( _cursor ) gdk_cursor_unref( _cursor );
-        }
+        { if( _cursor ) g_object_unref( G_OBJECT( _cursor ) ); }
 
         //! setup connections
         void connect( GtkWidget* );
