@@ -84,7 +84,7 @@ namespace Oxygen
     }
 
     //_____________________________________________
-    void ScrolledWindowData::disconnect( GtkWidget* )
+    void ScrolledWindowData::disconnect( GtkWidget* widget )
     {
         _target = 0;
         for( ChildDataMap::iterator iter = _childrenData.begin(); iter != _childrenData.end(); ++iter )
@@ -160,8 +160,11 @@ namespace Oxygen
             if( enabled && gtk_widget_get_window( widget ) )
             {
 
-                gint xPointer,yPointer;
-                gdk_window_get_pointer( gtk_widget_get_window( widget ), &xPointer, &yPointer, 0L );
+                gint xPointer(0),yPointer(0);
+                GdkDeviceManager* manager( gdk_display_get_device_manager( gtk_widget_get_display( widget ) ) );
+                GdkDevice* pointer( gdk_device_manager_get_client_pointer( manager ) );
+                gdk_window_get_device_position( gtk_widget_get_window( widget ), pointer, &xPointer, &yPointer, 0L);
+
                 const GtkAllocation allocation( Gtk::gtk_widget_get_allocation( widget ) );
                 const GdkRectangle rect( Gtk::gdk_rectangle( 0, 0, allocation.width, allocation.height ) );
                 setHovered( widget, Gtk::gdk_rectangle_contains( &rect, xPointer, yPointer ) );
