@@ -47,21 +47,24 @@ namespace Oxygen
         // get full-width flag
         if( GTK_IS_TREE_VIEW( widget ) )
         {
-            gtk_widget_style_get( widget, "row_ending_details", &_fullWidth, NULL );
+            /* TODO: row_ending_details is gone. See if there is a replacement */
+            // gtk_widget_style_get( widget, "row_ending_details", &_fullWidth, NULL );
+            _fullWidth = true;
 
             if( hovered() )
             {
                 // on connection, needs to check whether mouse pointer is in widget or not
                 // to have the proper initial value of the hover flag
                 GtkTreeView* treeView( GTK_TREE_VIEW( widget ) );
-                gint xPointer,yPointer;
-                gdk_window_get_pointer( gtk_widget_get_window( widget ), &xPointer, &yPointer, 0L );
+                gint xPointer(0), yPointer(0);
+                GdkDeviceManager* manager( gdk_display_get_device_manager( gtk_widget_get_display( widget ) ) );
+                GdkDevice* pointer( gdk_device_manager_get_client_pointer( manager ) );
+                gdk_window_get_device_position( gtk_widget_get_window( widget ), pointer, &xPointer, &yPointer, 0L);
+
                 gtk_tree_view_convert_widget_to_bin_window_coords( treeView, xPointer, yPointer, &xPointer, &yPointer );
                 updatePosition( widget, xPointer, yPointer );
             }
 
-            // columns changed signal connection
-            _columnsChangedId.connect( G_OBJECT(widget), "columns-changed", G_CALLBACK( columnsChanged ), this );
         }
 
         // motion notify signal connection
@@ -77,13 +80,12 @@ namespace Oxygen
     {
 
         #if OXYGEN_DEBUG
-        std::cerr << "Oxygen::TreeViewData::disconnect - " << widget << " (" << (widget ? G_OBJECT_TYPE_NAME( widget ):"null") << ")" << std::endl;
+        std::cerr << "Oxygen::TreeViewData::disconnect - " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")" << std::endl;
         #endif
 
         // reset target
         _target = 0L;
 
-        _columnsChangedId.disconnect();
         _motionId.disconnect();
 
         // also free path if valid
@@ -98,30 +100,6 @@ namespace Oxygen
 
     }
 
-    //________________________________________________________________________________
-    void TreeViewData::updateColumnsCursor( void ) const
-    {
-        // check tree view and target
-        if( !_cursor ) return;
-        if( !GTK_IS_TREE_VIEW( _target ) ) return;
-
-        #if OXYGEN_DEBUG
-        std::cerr << "Oxygen::TreeViewData::updateColumnsCursor - " << _target << " (" << G_OBJECT_TYPE_NAME( _target ) << ")" << std::endl;
-        #endif
-
-        GList* children( gtk_tree_view_get_columns( GTK_TREE_VIEW( _target ) ) );
-        for( GList *child = g_list_first( children ); child; child = g_list_next( child ) )
-        {
-            if( GTK_IS_TREE_VIEW_COLUMN( child->data ) )
-            {
-                GdkWindow* window( GTK_TREE_VIEW_COLUMN( child->data )->window );
-                gdk_window_set_cursor( window, _cursor );
-            }
-        }
-
-        if( children ) g_list_free( children );
-    }
-
     //________________________________________________________________________________
     void TreeViewData::updateHoveredCell( void )
     {
