@@ -21,20 +21,16 @@
 */
 
 #include "oxygenanimationmodes.h"
-#include "oxygenapplicationname.h"
+#include "oxygengtkcss.h"
 #include "oxygengtkicons.h"
-#include "oxygengtkrc.h"
 #include "oxygenoption.h"
 #include "oxygenoptionmap.h"
 #include "oxygenpalette.h"
 #include "oxygenshadowconfiguration.h"
-#include "oxygensignal.h"
 #include "oxygenpathlist.h"
 #include "oxygenfontinfo.h"
 #include "pango/pango.h"
 
-#include <gio/gio.h>
-
 #include <iostream>
 #include <sstream>
 #include <map>
@@ -54,8 +50,10 @@ namespace Oxygen
         QtSettings( void );
 
         //! destructor
-        virtual ~QtSettings( void )
-        { clearMonitoredFiles(); }
+        virtual ~QtSettings( void );
+
+        //! load kdeglobals settings into optionMap
+        void loadKdeGlobals( void );
 
         //! initialization flags
         enum Flags
@@ -66,8 +64,7 @@ namespace Oxygen
             KdeGlobals = 1<<3,
             Oxygen = 1<<4,
             Colors = 1<<5,
-            Extra = 1<<7,
-            All = AppName|Icons|Fonts|KdeGlobals|Oxygen|Colors|Extra,
+            All = AppName|Icons|Fonts|KdeGlobals|Oxygen|Colors,
             Forced = 1<<6
         };
 
@@ -76,16 +73,12 @@ namespace Oxygen
         { return _userConfigDir; }
 
         //! initialize
-        bool initialize( unsigned int flags = All );
+        void initialize( unsigned int flags = All );
 
         //! palette
         const Palette& palette( void ) const
         { return _palette; }
 
-        //! application name
-        const ApplicationName& applicationName( void ) const
-        { return _applicationName; }
-
         //!@name oxygen style options
         //@{
 
@@ -165,10 +158,6 @@ namespace Oxygen
         ArrowSize viewTriangularExpanderSize( void ) const
         { return _viewTriangularExpanderSize; }
 
-        //! true if views sort order indicator arrow direction must be inverted
-        bool viewInvertSortIndicator( void ) const
-        { return _viewInvertSortIndicator; }
-
         //! menu highlight mode
         enum MenuHighlightMode
         {
@@ -322,44 +311,12 @@ namespace Oxygen
         bool argbEnabled( void ) const
         { return _argbEnabled; }
 
-        //! file monitor structure
-        class FileMonitor
-        {
-            public:
-
-            //! constructor
-            FileMonitor( void ):
-                file( 0L ),
-                monitor( 0L )
-            {}
-
-            //! gfile pointer
-            GFile* file;
-            GFileMonitor* monitor;
-            Signal signal;
-        };
-
-        //! set of monitored files
-        typedef std::map<std::string, FileMonitor> FileMap;
-
-        //! file monitors
-        FileMap& monitoredFiles( void )
-        { return _monitoredFiles; }
-
         protected:
 
-        //! kdeglobals settings
-        /*! returns true if changed */
-        bool loadKdeGlobals( void );
-
-        //! oxygen settings
-        /*! returns true if changed */
-        bool loadOxygen( void );
-
-        //! kde configuration path
+        //! kde path
         PathList kdeConfigPathList( void ) const;
 
-        //! kde icon path
+        //! icon path
         PathList kdeIconPathList( void ) const;
 
         //! add icon theme to path list, accounting for theme inheritance (recursively)
@@ -370,7 +327,7 @@ namespace Oxygen
 
         //! init application name
         void initApplicationName( void )
-        { _applicationName.initialize(); }
+        {}
 
         //! init argb support
         void initArgb( void );
@@ -378,9 +335,6 @@ namespace Oxygen
         //! load kde icons
         void loadKdeIcons( void );
 
-        //! default icon search path
-        PathSet defaultIconSearchPath( void ) const;
-
         //! load palette from kdeglobals
         void loadKdePalette( bool forced = false );
 
@@ -397,30 +351,14 @@ namespace Oxygen
         //! oxygen options (from oxygenrc)
         void loadOxygenOptions( void );
 
-        //! extra metrics options
-        void loadExtraOptions( void );
-
-        //! sanitize path
+        // sanitize path
         std::string sanitizePath( const std::string& ) const;
 
-        //! monitor file
-        void monitorFile( const std::string& );
-
-        //! clear monitored files
-        void clearMonitoredFiles( void );
-
         private:
 
-        //! application
-        /*! this is needed to deal with some application hacks */
-        ApplicationName _applicationName;
-
         //! kde global options
         OptionMap _kdeGlobals;
 
-        //! oxygen options
-        OptionMap _oxygen;
-
         //! user config directory
         std::string _userConfigDir;
 
@@ -499,9 +437,6 @@ namespace Oxygen
         //! triangular expander size
         ArrowSize _viewTriangularExpanderSize;
 
-        //! true if views sort order indicator arrow direction must be inverted
-        bool _viewInvertSortIndicator;
-
         //! menu highlight mode
         MenuHighlightMode _menuHighlightMode;
 
@@ -594,14 +529,14 @@ namespace Oxygen
         //! KDE running flags
         bool _KDESession;
 
-        //! gtk icons generator
+        //! icons generation
         GtkIcons _icons;
 
-        //! gtkrc
-        Gtk::RC _rc;
+        //! internal gtk style sheet
+        Gtk::CSS _css;
 
-        //! file monitors
-        FileMap _monitoredFiles;
+        //! internal gtk style provided
+        GtkCssProvider* _provider;
 
     };
 
