@@ -22,6 +22,7 @@
 #include "oxygencairoutils.h"
 #include "config.h"
 #include "oxygengtkutils.h"
+#include "oxygengtktypenames.h"
 #include "oxygenmetrics.h"
 #include "oxygenrgba.h"
 #include "oxygenshadowhelper.h"
@@ -30,12 +31,9 @@
 
 #include <iostream>
 #include <cairo/cairo.h>
-
-#ifdef GDK_WINDOWING_X11
 #include <cairo/cairo-xlib.h>
 #include <gdk/gdkx.h>
 #include <X11/Xatom.h>
-#endif
 
 namespace Oxygen
 {
@@ -43,13 +41,9 @@ namespace Oxygen
     //______________________________________________
     ShadowHelper::ShadowHelper( void ):
         _size(0),
+        _atom(0),
         _hooksInitialized( false )
     {
-
-        #ifdef GDK_WINDOWING_X11
-        _atom = None;
-        #endif
-
         #if OXYGEN_DEBUG
         std::cerr << "Oxygen::ShadowHelper::ShadowHelper" << std::endl;
         #endif
@@ -63,8 +57,6 @@ namespace Oxygen
         #endif
 
         reset();
-        _realizeHook.disconnect();
-
     }
 
     //______________________________________________
@@ -75,23 +67,23 @@ namespace Oxygen
         std::cerr << "Oxygen::ShadowHelper::reset" << std::endl;
         #endif
 
-        #ifdef GDK_WINDOWING_X11
         GdkScreen* screen = gdk_screen_get_default();
         if( !screen ) return;
 
+        #if OXYGEN_DEBUG
+        std::cerr << "Oxygen::ShadowHelper::~ShadowHelper - reset" << std::endl;
+        #endif
+
         Display* display( GDK_DISPLAY_XDISPLAY( gdk_screen_get_display( screen ) ) );
 
         // round pixmaps
         for( PixmapList::const_iterator iter = _roundPixmaps.begin(); iter != _roundPixmaps.end(); ++iter )
         { XFreePixmap(display, *iter); }
+        _roundPixmaps.clear();
 
         // square pixmaps
         for( PixmapList::const_iterator iter = _squarePixmaps.begin(); iter != _squarePixmaps.end(); ++iter )
         { XFreePixmap(display, *iter); }
-        #endif
-
-        // clear arrays
-        _roundPixmaps.clear();
         _squarePixmaps.clear();
 
         // reset size
@@ -186,10 +178,16 @@ namespace Oxygen
     {
         if( !( widget && GTK_IS_WINDOW( widget ) ) ) return false;
         const GdkWindowTypeHint hint( gtk_window_get_type_hint( GTK_WINDOW( widget ) ) );
-        return
+        if(
             hint == GDK_WINDOW_TYPE_HINT_MENU ||
             hint == GDK_WINDOW_TYPE_HINT_DROPDOWN_MENU ||
-            hint == GDK_WINDOW_TYPE_HINT_POPUP_MENU;
+            hint == GDK_WINDOW_TYPE_HINT_POPUP_MENU ) return true;
+
+        // also manually check for menu
+        if( GTK_IS_MENU( gtk_bin_get_child( GTK_BIN( widget ) ) ) )
+        { return true; }
+
+        return false;
     }
 
     //______________________________________________
@@ -207,17 +205,21 @@ namespace Oxygen
         // check widget and type
         if( !( widget && GTK_IS_WINDOW( widget ) ) ) return false;
 
-        // for openoffice, accept all non decorated windows
-        if( _applicationName.isOpenOffice() ) return true;
-
         // otherwise check window hint
         const GdkWindowTypeHint hint( gtk_window_get_type_hint( GTK_WINDOW( widget ) ) );
-        return
+        if(
             hint == GDK_WINDOW_TYPE_HINT_MENU ||
             hint == GDK_WINDOW_TYPE_HINT_DROPDOWN_MENU ||
             hint == GDK_WINDOW_TYPE_HINT_POPUP_MENU ||
             hint == GDK_WINDOW_TYPE_HINT_COMBO ||
-            hint == GDK_WINDOW_TYPE_HINT_TOOLTIP;
+            hint == GDK_WINDOW_TYPE_HINT_TOOLTIP ) return true;
+
+        // also manually check for menu
+        if( GTK_IS_MENU( gtk_bin_get_child( GTK_BIN( widget ) ) ) )
+        { return true; }
+
+        return false;
+
     }
 
     //______________________________________________
@@ -228,7 +230,6 @@ namespace Oxygen
         std::cerr << "Oxygen::ShadowHelper::createPixmapHandles" << std::endl;
         #endif
 
-        #ifdef GDK_WINDOWING_X11
         // create atom
         if( !_atom )
         {
@@ -312,18 +313,14 @@ namespace Oxygen
 
         }
 
-        #endif
-
     }
 
     //______________________________________________
-    #ifdef GDK_WINDOWING_X11
     Pixmap ShadowHelper::createPixmap( const Cairo::Surface& surface, int opacity ) const
     {
         assert( surface.isValid() );
-        int width(0);
-        int height(0);
-        cairo_surface_get_size( surface, width, height );
+        const int width( cairo_surface_get_width( surface ) );
+        const int height( cairo_surface_get_height( surface ) );
 
         GdkScreen* screen = gdk_screen_get_default();
         Display* display( GDK_DISPLAY_XDISPLAY( gdk_screen_get_display( screen ) ) );
@@ -355,14 +352,11 @@ namespace Oxygen
         return pixmap;
 
     }
-    #endif
 
     //______________________________________________
     void ShadowHelper::installX11Shadows( GtkWidget* widget )
     {
 
-        #ifdef GDK_WINDOWING_X11
-
         #if OXYGEN_DEBUG
         std::cerr
             << "Oxygen::ShadowHelper::installX11Shadows - "
@@ -371,9 +365,6 @@ namespace Oxygen
             << std::endl;
         #endif
 
-        // check widget
-        if( !GTK_IS_WIDGET( widget ) ) return;
-
         // make sure handles and atom are defined
         createPixmapHandles();
 
@@ -382,40 +373,27 @@ namespace Oxygen
 
         std::vector<unsigned long> data;
         const bool isMenu( this->isMenu( widget ) );
-        const bool isToolTip( this->isToolTip( widget ) );
-        if( _applicationName.isOpenOffice() || ( (isMenu||isToolTip) && _applicationName.isXul( widget ) ) )
+
+        data = _roundPixmaps;
+        if( isMenu )
         {
 
-            data = _squarePixmaps;
-            data.push_back( _size );
-            data.push_back( _size );
+            /*
+            for menus, need to shrink top and bottom shadow size, since body is done likely with respect to real size
+            in painting method (Oxygen::Style::renderMenuBackground)
+            */
+            data.push_back( _size - Menu_VerticalOffset );
             data.push_back( _size );
+            data.push_back( _size - Menu_VerticalOffset );
             data.push_back( _size );
 
         } else {
 
-            data = _roundPixmaps;
-            if( isMenu )
-            {
-
-                /*
-                for menus, need to shrink top and bottom shadow size, since body is done likely with respect to real size
-                in painting method (Oxygen::Style::renderMenuBackground)
-                */
-                data.push_back( _size - Menu_VerticalOffset );
-                data.push_back( _size );
-                data.push_back( _size - Menu_VerticalOffset );
-                data.push_back( _size );
-
-            } else {
-
-                // all sides have same sizz
-                data.push_back( _size );
-                data.push_back( _size );
-                data.push_back( _size );
-                data.push_back( _size );
-
-            }
+            // all sides have same sizz
+            data.push_back( _size );
+            data.push_back( _size );
+            data.push_back( _size );
+            data.push_back( _size );
 
         }
 
@@ -424,21 +402,17 @@ namespace Oxygen
             GDK_DISPLAY_XDISPLAY( display ), GDK_WINDOW_XID(window), _atom, XA_CARDINAL, 32, PropModeReplace,
             reinterpret_cast<const unsigned char *>(&data[0]), data.size() );
 
-        #endif
-
     }
 
     //_______________________________________________________
     void ShadowHelper::uninstallX11Shadows( GtkWidget* widget ) const
     {
 
-        if( !GTK_IS_WIDGET( widget ) ) return;
+        if( !widget ) return;
 
-        #ifdef GDK_WINDOWING_X11
         GdkWindow  *window = gtk_widget_get_window( widget );
         GdkDisplay *display = gtk_widget_get_display( widget );
         XDeleteProperty( GDK_DISPLAY_XDISPLAY( display ), GDK_WINDOW_XID(window), _atom);
-        #endif
 
     }
 
