@@ -26,6 +26,7 @@
 
 #include <cmath>
 #include <gdk/gdk.h>
+#include <gdk/gdkx.h>
 
 namespace Oxygen
 {
@@ -37,19 +38,7 @@ namespace Oxygen
 
     //__________________________________________________________________
     StyleHelper::StyleHelper( void )
-    {
-        #if OXYGEN_DEBUG
-        std::cerr << "Oxygen::StyleHelper::StyleHelper" << std::endl;
-        #endif
-    }
-
-    //__________________________________________________________________
-    StyleHelper::~StyleHelper( void )
-    {
-        #if OXYGEN_DEBUG
-        std::cerr << "Oxygen::StyleHelper::~StyleHelper" << std::endl;
-        #endif
-    }
+    {}
 
     //__________________________________________________________________
     void StyleHelper::initializeRefSurface( void )
@@ -100,7 +89,7 @@ namespace Oxygen
     }
 
     //__________________________________________________________________
-    void StyleHelper::drawSeparator( Cairo::Context& context, const ColorUtils::Rgba& base, int x, int y, int w, int h, bool vertical )
+    void StyleHelper::drawSeparator( cairo_t* context, const ColorUtils::Rgba& base, int x, int y, int w, int h, bool vertical )
     {
 
         // get surface
@@ -109,18 +98,10 @@ namespace Oxygen
 
         // translate
         cairo_save( context );
-        if( vertical ) {
-
-            cairo_translate( context, x+w/2-1, y );
-            cairo_rectangle( context, 0, 0, 3, h );
-
-        } else {
-
-            cairo_translate( context, x, y+h/2 );
-            cairo_rectangle( context, 0, 0, w, 2 );
-
-        }
+        if( vertical ) cairo_translate( context, x+w/2-1, y );
+        else cairo_translate( context, x, y+h/2 );
 
+        cairo_rectangle( context, 0, 0, cairo_surface_get_width( surface ), cairo_surface_get_height( surface ) );
         cairo_set_source_surface( context, surface, 0, 0 );
         cairo_fill( context );
         cairo_restore( context );
@@ -237,7 +218,7 @@ namespace Oxygen
 
         // create cairo context
         Cairo::Context context( surface );
-        const double u = size/18.0;
+        const double u = double(size)/18.0;
         cairo_translate( context, 0.5*u, (0.5-0.668)*u );
 
         {
@@ -296,7 +277,7 @@ namespace Oxygen
         const ColorUtils::Rgba& dark( base );
 
         Cairo::Context context( surface );
-        const double u = size/18.0;
+        const double u = double(size)/18.0;
         cairo_translate( context, 0.5*u, (0.5-0.668)*u );
 
         {
@@ -416,7 +397,7 @@ namespace Oxygen
         {
             // create cairo context
             Cairo::Context context( surface );
-            cairo_scale( context, size/7.0, size/7.0 );
+            cairo_scale( context, double(size)/7, double(size)/7 );
             cairo_rectangle( context, 0, 0, 14, 14 );
             cairo_set_source( context, ColorUtils::Rgba::transparent( base ) );
             cairo_fill( context );
@@ -450,7 +431,7 @@ namespace Oxygen
             // create cairo context
             Cairo::Context context( surface );
             cairo_set_line_width( context, 1.0 );
-            cairo_scale( context, size/7.0, size/7.0 );
+            cairo_scale( context, double(size)/7, double(size)/7 );
             cairo_rectangle( context, 0, 0, 14, 14 );
             cairo_set_source( context, ColorUtils::Rgba::transparent( base ) );
             cairo_fill( context );
@@ -496,7 +477,7 @@ namespace Oxygen
 
         // create cairo context
         Cairo::Context context( surface );
-        cairo_scale( context, size/7.0, size/7.0 );
+        cairo_scale( context, double(size)/7, double(size)/7 );
 
         // shadow
         if( base.isValid() ) drawShadow( context, ColorUtils::shadowColor(base), 21 );
@@ -527,17 +508,16 @@ namespace Oxygen
 
         {
             Cairo::Context context( surface );
-            cairo_set_antialias( context, CAIRO_ANTIALIAS_SUBPIXEL );
 
             cairo_save( context );
-            cairo_scale( context, 3.0*size/23, 3.0*size/23 );
+            cairo_scale( context, double( 3*size )/23, double( 3*size )/23 );
             cairo_translate( context, 1, 1 );
 
             if( base.isValid() ) drawShadow( context, ColorUtils::alphaColor( ColorUtils::shadowColor(base), 0.8 ), 21 );
             if( glow.isValid() ) drawOuterGlow( context, glow, 21 );
             cairo_restore( context );
 
-            cairo_scale( context, 3.0*size/25, 3.0*size/25 );
+            cairo_scale( context, double( 3*size )/25, double( 3*size )/25 );
             cairo_translate( context, 2, 2 );
             drawSliderSlab( context, base, sunken, shade );
 
@@ -591,34 +571,38 @@ namespace Oxygen
         }
 
 
-        cairo_rounded_rectangle( context, x+s, y+s, w-2*s, h-2*s, r, corners );
+        cairo_rounded_rectangle( context, double(x)+s, double(y)+s, double(w)-2*s, double(h)-2*s, r, corners );
         cairo_fill( context );
     }
 
-    //__________________________________________________________________
-    GdkPixmap* StyleHelper::roundMask( int w, int h, int radius ) const
+    //_______________________________________________________________________
+    Cairo::Region StyleHelper::roundMask( int w, int h ) const
     {
-
-        GdkPixmap* mask( gdk_pixmap_new( 0L, w, h, 1 ) );
-
+        cairo_rectangle_int_t rectangles[] =
         {
-            Cairo::Context context( GDK_DRAWABLE(mask) );
+            { 4, 0, w-8, h },
+            { 0, 4, w, h-8 },
+            { 2, 1, w-4, h-2 },
+            { 1, 2, w-2, h-4 }
+        };
 
-            // clear the window
-            cairo_set_operator( context, CAIRO_OPERATOR_SOURCE );
-            cairo_set_source( context, ColorUtils::Rgba::transparent() );
-            cairo_paint( context );
+        int numOfRectangles(sizeof(rectangles)/sizeof(cairo_rectangle_int_t));
 
-            // now draw roundrect mask
-            cairo_set_operator( context, CAIRO_OPERATOR_OVER );
-            cairo_set_source( context, ColorUtils::Rgba::black() );
+        return Cairo::Region( cairo_region_create_rectangles( rectangles, numOfRectangles ) );
 
-            // FIXME: radius found empirically
-            cairo_rounded_rectangle( context, 0, 0, w, h, radius );
-            cairo_fill( context );
-        }
+    }
+    //_______________________________________________________________________
+    Cairo::Region StyleHelper::innerRoundMask( int w, int h ) const
+    {
+        cairo_rectangle_int_t rectangles[] =
+        {
+            { 1, 0, w-2, h },
+            { 0, 1, w, h-2 }
+        };
 
-        return mask;
+        int numOfRectangles(sizeof(rectangles)/sizeof(cairo_rectangle_int_t));
+
+        return Cairo::Region( cairo_region_create_rectangles( rectangles, numOfRectangles ) );
 
     }
 
@@ -1060,7 +1044,7 @@ namespace Oxygen
 
         {
             // shadow
-            cairo_rounded_rectangle( context, xl+0.5, yl+0.5, wl-1, hl, 3.0 );
+            cairo_rounded_rectangle( context, double(xl)+0.5, double(yl)+0.5, wl-1, hl, 3.0 );
             cairo_set_source( context, ColorUtils::alphaColor( shadow, 0.6 ) );
             cairo_set_line_width( context, 0.6 );
             cairo_stroke( context );
@@ -1118,21 +1102,21 @@ namespace Oxygen
             cairo_pattern_add_color_stop( pattern, 1.0, ColorUtils::darkColor(highlight) );
             cairo_set_line_width( context, 1.0 );
             cairo_set_source( context, pattern );
-            cairo_rounded_rectangle( context, xl+0.5, yl+0.5, wl-1, hl-1, 2.5 );
+            cairo_rounded_rectangle( context, double(xl)+0.5, double(yl)+0.5, wl-1, hl-1, 2.5 );
             cairo_stroke( context );
         }
 
         {
             // bright top edge
-            Cairo::Pattern pattern( cairo_pattern_create_linear( xl, 0, xl+wl, 0 ) );
+            Cairo::Pattern pattern( cairo_pattern_create_linear( 0, 0, wl, 0 ) );
             const ColorUtils::Rgba mix( ColorUtils::mix( lhighlight, light, 0.8 ) );
             cairo_pattern_add_color_stop( pattern, 0.0, ColorUtils::Rgba::transparent( mix ) );
             cairo_pattern_add_color_stop( pattern, 0.5, mix );
             cairo_pattern_add_color_stop( pattern, 1.0, ColorUtils::Rgba::transparent( mix ) );
             cairo_set_line_width( context, 1.0 );
             cairo_set_source( context, pattern );
-            cairo_move_to( context, xl+0.5, yl+0.5 );
-            cairo_line_to( context, xl+wl-0.5, yl+0.5 );
+            cairo_move_to( context, double(xl)+0.5, double(yl)+0.5 );
+            cairo_line_to( context, double(xl+wl)-0.5, double(yl)+0.5 );
             cairo_stroke( context );
         }
 
@@ -1150,7 +1134,7 @@ namespace Oxygen
         const TileSet& tileSet( _grooveCache.value( key ) );
         if( tileSet.isValid() ) return tileSet;
 
-        const int rsize( int( ceil( size * 3.0/7.0 ) ) );
+        const int rsize( ( int )ceil( double( size ) * 3.0/7.0 ) );
         const int w( rsize*2 );
         const int h( rsize*2 );
         Cairo::Surface surface( createSurface( w, h ) );
@@ -1212,7 +1196,7 @@ namespace Oxygen
                 cairo_pattern_add_color_stop( pattern, 0, base );
                 cairo_pattern_add_color_stop( pattern, 1, ColorUtils::Rgba::transparent() );
 
-                cairo_rounded_rectangle( context, x+0.5, y+0.5, w-1, h-1, rounding );
+                cairo_rounded_rectangle( context, double(x)+0.5, double(y)+0.5, w-1, h-1, rounding );
                 cairo_set_source( context, pattern );
                 cairo_stroke( context );
             }
@@ -1231,11 +1215,11 @@ namespace Oxygen
         const ColorUtils::Rgba light( ColorUtils::lightColor( base ) );
         const ColorUtils::Rgba dark( ColorUtils::darkColor( base ).dark(130) );
 
-        cairo_ellipse( context, x + 1.0 - diameter/2, y + 1.0 - diameter/2.0, diameter, diameter );
+        cairo_ellipse( context, double(x) + 1.0 - diameter/2, double(y) + 1.0 - diameter/2.0, diameter, diameter );
         cairo_set_source( context, light );
         cairo_fill( context );
 
-        cairo_ellipse( context, x + 0.5 - diameter/2, y + 0.5 - diameter/2.0, diameter, diameter );
+        cairo_ellipse( context, double(x) + 0.5 - diameter/2, double(y) + 0.5 - diameter/2.0, diameter, diameter );
         cairo_set_source( context, dark );
         cairo_fill( context );
     }
@@ -1303,10 +1287,10 @@ namespace Oxygen
     }
 
     //___________________________________________________________________________________________
-    void StyleHelper::drawShadow( cairo_t* context, const ColorUtils::Rgba& base, int size ) const
+    void StyleHelper::drawShadow( Cairo::Context& context, const ColorUtils::Rgba& base, int size ) const
     {
 
-        const double m( 0.5*size-1 );
+        const double m( double(size-2)*0.5 );
         const double offset( 0.8 );
         const double k0( (m-4.0) / m );
 
@@ -1317,7 +1301,7 @@ namespace Oxygen
         for (int i = 0; i < 8; i++)
         {
             // sinusoidal pattern
-            const double k1( (k0 * (8 - i) + i) * 0.125 );
+            const double k1( (k0 * double(8 - i) + double(i)) * 0.125 );
             const double a( (cos( M_PI * i * 0.125) + 1.0) * 0.30 );
             cairo_pattern_add_color_stop( pattern, k1, ColorUtils::alphaColor( base, a*_shadowGain ) );
         }
@@ -1330,13 +1314,13 @@ namespace Oxygen
     }
 
     //_______________________________________________________________________
-    void StyleHelper::drawOuterGlow( cairo_t* context, const ColorUtils::Rgba& base, int size ) const
+    void StyleHelper::drawOuterGlow( Cairo::Context& context, const ColorUtils::Rgba& base, int size ) const
     {
 
-        const double m( size*0.5 );
+        const double m( double(size)*0.5 );
         const double w( 3 );
 
-        const double bias( _glowBias * 14.0/size );
+        const double bias( _glowBias * double(14)/size );
 
         // k0 is located at w - bias from the outer edge
         const double gm( m + bias - 0.9 );
@@ -1346,8 +1330,8 @@ namespace Oxygen
         for (int i = 0; i < 8; i++)
         {
             // parabolic pattern
-            const double k1( k0 + i*(1.0-k0)/8.0 );
-            const double a( 1.0 - sqrt(i/8.0) );
+            const double k1( k0 + double(i)*(1.0-k0)/8.0 );
+            const double a( 1.0 - sqrt(double(i)/8) );
             cairo_pattern_add_color_stop( pattern, k1, ColorUtils::alphaColor( base, a ) );
         }
 
@@ -1386,7 +1370,7 @@ namespace Oxygen
         int pad, int size, int rsize ) const
     {
 
-        const double m( size*0.5 );
+        const double m( double( size )*0.5 );
 
         const double width( 3.5 );
         const double bias( _glowBias*7.0/rsize );
@@ -1395,7 +1379,7 @@ namespace Oxygen
         for ( int i = 0; i < 8; i++ )
         {
             // inverse parabolic gradient
-            double k1 = ( k0 * i + 8 - i ) * 0.125;
+            double k1 = ( k0 * double( i ) + double( 8 - i ) ) * 0.125;
             double a = 1.0 - sqrt( i * 0.125 );
             cairo_pattern_add_color_stop( pattern, k1, ColorUtils::alphaColor( base, a ) );
 
@@ -1508,9 +1492,9 @@ namespace Oxygen
         int pad, int size, double fuzz ) const
     {
 
-        const double m( size*0.5 );
+        const double m( double(size)*0.5 );
         const double offset( 0.8 );
-        const double k0( (m-2) / (m+2.0) );
+        const double k0( (m-2) / double(m+2.0) );
 
         const double x(pad+m);
         const double y(pad+m+offset);
@@ -1519,7 +1503,7 @@ namespace Oxygen
         for (int i = 0; i < 8; i++)
         {
             // sinusoidal pattern
-            const double k1( (8 - i + k0 * i) * 0.125 );
+            const double k1( (double(8 - i) + k0 * double(i)) * 0.125 );
             const double a( (cos(3.14159 * i * 0.125) + 1.0) * 0.25 );
             cairo_pattern_add_color_stop( pattern, k1, ColorUtils::alphaColor( base, a*_shadowGain ) );
         }
@@ -1530,43 +1514,4 @@ namespace Oxygen
     }
 
 
-    //________________________________________________________________________________________________________
-    const Cairo::Surface& StyleHelper::dockWidgetButton(const ColorUtils::Rgba& base, bool pressed, int size)
-    {
-        const DockWidgetButtonKey key( base, pressed, size );
-
-        // try find in cache and return
-        if( const Cairo::Surface& surface = _dockWidgetButtonCache.value(key) )
-        { return surface; }
-
-        // cached not found, create new
-        Cairo::Surface surface( createSurface( size, size ) );
-
-        Cairo::Context context( surface );
-        cairo_set_source( context, ColorUtils::Rgba::transparent( base ) );
-        cairo_paint( context );
-
-        const ColorUtils::Rgba light( ColorUtils::lightColor( base ) );
-        const ColorUtils::Rgba dark( ColorUtils::darkColor( base ) );
-
-        const double u( size/18.0 );
-        cairo_translate( context, 0.5*u, ( 0.5-0.668 )*u );
-
-        {
-            // outline circle
-            double penWidth = 1.2;
-            Cairo::Pattern lg( cairo_pattern_create_linear( 0, u*( 1.665-penWidth ), 0, u*( 12.33+1.665-penWidth ) ) );
-
-            cairo_pattern_add_color_stop( lg, 0, dark );
-            cairo_pattern_add_color_stop( lg, 1, light );
-            cairo_set_source( context, lg );
-            cairo_set_line_width( context, penWidth*u );
-            cairo_ellipse( context, u*0.5*( 17-12.33+penWidth ), u*( 1.665+penWidth ), u*( 12.33-penWidth ), u*( 12.33-penWidth ) );
-            cairo_stroke( context );
-        }
-
-        return _dockWidgetButtonCache.insert(key, surface);
-    }
-
-
 }
