@@ -4,7 +4,7 @@
 * -------------------
 *
 * Copyright (c) 2010 Cédric Bellegarde <gnumdk@gmail.com>
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
 *
 * Largely inspired from Qtcurve style
 * Copyright (C) Craig Drummond, 2003 - 2010 craig.p.drummond@gmail.com
@@ -26,37 +26,27 @@
 */
 
 #include "oxygenwindowmanager.h"
-#include "oxygenpropertynames.h"
 #include "oxygenstyle.h"
 #include "config.h"
 
+#include <gdk/gdkx.h>
+
 namespace Oxygen
 {
 
 
     //_________________________________________________
     WindowManager::WindowManager( void ):
-        _useWMMoveResize( true ),
-        _cursorLoaded( false ),
-        _cursor( 0L ),
-        _oldCursor( 0L ),
-        _dragMode( Full ),
+        _mode( Full ),
         _hooksInitialized( false ),
-        _dragAboutToStart( false ),
-        _dragInProgress( false ),
+        _drag( false ),
         _dragDistance( 4 ),
         _dragDelay( 500 ),
         _widget( 0L ),
         _lastRejectedEvent( 0L ),
         _x(-1),
-        _y(-1),
-        _globalX(-1),
-        _globalY(-1),
-        _time(0)
+        _y(-1)
     {
-        #if OXYGEN_DEBUG
-        std::cerr << "Oxygen::WindowManager::WindowManager" << std::endl;
-        #endif
 
         // black list
         initializeBlackList();
@@ -66,19 +56,10 @@ namespace Oxygen
     //_________________________________________________
     WindowManager::~WindowManager( void )
     {
-
-        #if OXYGEN_DEBUG
-        std::cerr << "Oxygen::WindowManager::~WindowManager" << std::endl;
-        #endif
-
         _styleSetHook.disconnect();
         _buttonReleaseHook.disconnect();
         _map.disconnectAll();
         _map.clear();
-
-        // cursor
-        if( _cursor ) gdk_cursor_unref( _cursor );
-
     }
 
     //_________________________________________________
@@ -86,11 +67,8 @@ namespace Oxygen
     {
 
         if( _hooksInitialized ) return;
-        if( _dragMode!=Disabled )
-        {
-            _styleSetHook.connect( "style-set", (GSignalEmissionHook)styleSetHook, this );
-            _buttonReleaseHook.connect( "button-release-event", (GSignalEmissionHook)buttonReleaseHook, this );
-        }
+        _styleSetHook.connect( "style-updated", (GSignalEmissionHook)styleSetHook, this );
+        _buttonReleaseHook.connect( "button-release-event", (GSignalEmissionHook)buttonReleaseHook, this );
         _hooksInitialized = true;
 
     }
@@ -99,37 +77,10 @@ namespace Oxygen
     bool WindowManager::registerWidget( GtkWidget* widget )
     {
 
-        // load cursor if needed
-        if( !_cursorLoaded )
-        {
-            assert( !_cursor );
-            GdkDisplay *display( gtk_widget_get_display( widget ) );
-            _cursor = gdk_cursor_new_from_name( display, "all-scroll" );
-            _cursorLoaded = true;
-        }
-
-        if( _map.contains( widget ) ) return false;
-
-        // check against black listed typenames
-        if( widgetIsBlackListed( widget ) )
-        {
-            registerBlackListWidget( widget );
-            return false;
-        }
-
-        // check blocking property
-        if( g_object_get_data( G_OBJECT( widget ), PropertyNames::noWindowGrab ) )
-        {
-            registerBlackListWidget( widget );
-            return false;
-        }
+        if( _map.contains( widget ) || widgetIsBlackListed( widget ) ) return false;
 
         // Window with no decorations (set by app), let window manage it self
-        if( GTK_IS_WINDOW( widget ) && !gtk_window_get_decorated( GTK_WINDOW( widget ) ) )
-        {
-            registerBlackListWidget( widget );
-            return false;
-        }
+        if( GTK_IS_WINDOW( widget ) && !gtk_window_get_decorated( GTK_WINDOW( widget ) ) ) return false;
 
         // widgets used in tabs also must be ignored (happens, unfortunately)
         GtkWidget* parent( gtk_widget_get_parent( widget ) );
@@ -143,16 +94,9 @@ namespace Oxygen
         in which case we should not use them for grabbing
         */
         if(
-            ( GTK_IS_WINDOW( widget ) || GTK_IS_VIEWPORT( widget ) ) &&
-            ( gtk_widget_get_events ( widget ) &
-            ( GDK_BUTTON_PRESS_MASK|GDK_BUTTON_RELEASE_MASK ) ) )
-        {
-            registerBlackListWidget( widget );
-            return false;
-        }
-
-        // check for blacklisted parent
-        if( widgetHasBlackListedParent( widget ) )
+            std::string( G_OBJECT_TYPE_NAME( widget ) ) == "GtkWindow" &&
+            (gtk_widget_get_events ( widget ) &
+            (GDK_BUTTON_PRESS_MASK|GDK_BUTTON_RELEASE_MASK) ) )
         { return false; }
 
         #if OXYGEN_DEBUG
@@ -174,7 +118,7 @@ namespace Oxygen
         Data& data( _map.registerWidget( widget ) );
 
         // connect signals
-        if( _dragMode != Disabled ) connect( widget, data );
+        if( _mode != Disabled ) connect( widget, data );
         return true;
 
     }
@@ -191,54 +135,24 @@ namespace Oxygen
         _map.value( widget ).disconnect( widget );
         _map.erase( widget );
 
-        // reset drag is the current drag target
-        if( _widget == widget ) resetDrag();
+        if( _widget == widget )
+        {
+            _widget = 0L;
+            _x = -1;
+            _y = -1;
+            _drag = false;
+        }
 
     }
 
     //_________________________________________________
-    bool WindowManager::registerBlackListWidget( GtkWidget* widget )
+    void WindowManager::setMode( WindowManager::Mode mode )
     {
-
-        // make sure that widget is not already connected
-        if( _blackListWidgets.find( widget ) != _blackListWidgets.end() ) return false;
-
-        #if OXYGEN_DEBUG
-        std::cerr << "Oxygen::WindowManager::registerBlackListWidget - " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")" << std::endl;
-        #endif
-
-      // connect destroy signal and insert in map
-        Signal destroyId;
-        destroyId.connect( G_OBJECT( widget ), "destroy", G_CALLBACK( wmBlackListDestroy ), this );
-        _blackListWidgets.insert( std::make_pair( widget, destroyId ) );
-        return true;
-
-    }
-
-    //_________________________________________________
-    void WindowManager::unregisterBlackListWidget( GtkWidget* widget )
-    {
-
-        WidgetMap::iterator iter( _blackListWidgets.find( widget ) );
-        if( iter == _blackListWidgets.end() ) return;
-
-        #if OXYGEN_DEBUG
-        std::cerr << "Oxygen::WindowManager::unregisterBlackListWidget - " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")" << std::endl;
-        #endif
-
-        iter->second.disconnect();
-        _blackListWidgets.erase( widget );
-
-    }
-
-    //_________________________________________________
-    void WindowManager::setDragMode( WindowManager::Mode mode )
-    {
-        if( mode == _dragMode ) return;
+        if( mode == _mode ) return;
 
         // connect/disconnect all data in map, based on new and old mode
         if( mode == Disabled ) { _map.disconnectAll(); }
-        else if( _dragMode == Disabled )
+        else if( _mode == Disabled )
         {
             DataMap<Data>::Map& map( _map.map() );
             for( DataMap<Data>::Map::iterator iter = map.begin(); iter != map.end(); ++iter )
@@ -246,7 +160,7 @@ namespace Oxygen
         }
 
         // assign new mode
-        _dragMode = mode;
+        _mode = mode;
 
     }
 
@@ -257,13 +171,6 @@ namespace Oxygen
         return false;
     }
 
-    //_________________________________________________
-    gboolean WindowManager::wmBlackListDestroy( GtkWidget* widget, gpointer data )
-    {
-        static_cast<WindowManager*>(data)->unregisterBlackListWidget( widget );
-        return false;
-    }
-
     //_________________________________________________
     gboolean WindowManager::wmButtonPress(GtkWidget *widget, GdkEventButton* event, gpointer data )
     {
@@ -271,7 +178,7 @@ namespace Oxygen
         if( event->type == GDK_BUTTON_PRESS && event->button == Gtk::LeftButton )
         {
 
-            const bool accepted( static_cast<WindowManager*>(data)->canDrag( widget, event ) );
+            const bool accepted( static_cast<WindowManager*>(data)->isWindowDragWidget( widget, event ) );
             #if OXYGEN_DEBUG
             std::cerr << "Oxygen::WindowManager::wmButtonPress -"
                 << " event: " << event
@@ -290,10 +197,7 @@ namespace Oxygen
 
     //_________________________________________________
     gboolean WindowManager::wmLeave(GtkWidget*, GdkEventCrossing*, gpointer data )
-    {
-        WindowManager& manager( *static_cast<WindowManager*>( data ) );
-        return (gboolean) ( manager.useWMMoveResize() && manager.resetDrag() );
-    }
+    { return (gboolean) static_cast<WindowManager*>( data )->finishDrag(); }
 
     //_________________________________________________
     gboolean WindowManager::wmMotion( GtkWidget *widget, GdkEventMotion* event, gpointer data )
@@ -371,10 +275,10 @@ namespace Oxygen
         WindowManager &manager( *static_cast<WindowManager*>(data ) );
 
         // check mode
-        if( manager._dragMode == Disabled ) return TRUE;
+        if( manager._mode == Disabled ) return TRUE;
 
         // check if drag is in progress, and reset if yes
-        if( manager._dragAboutToStart || manager._dragInProgress )
+        if( manager._drag )
         {
 
             #if OXYGEN_DEBUG
@@ -384,12 +288,7 @@ namespace Oxygen
                 << " " << gtk_widget_get_name( widget )
                 << std::endl;
             #endif
-
-            // reset cursor
-            if( !manager._useWMMoveResize && manager._dragInProgress )
-            { manager.unsetCursor( widget ); }
-
-            manager.resetDrag();
+            manager.finishDrag();
 
         }
 
@@ -401,102 +300,81 @@ namespace Oxygen
     {
 
         // make sure drag is enabled
-        if( !_dragAboutToStart ) return false;
+        if( !_drag ) return false;
 
-        // check displacement with respect to drag start, as long as not already started
-        if( !_dragInProgress )
-        {
-            const int distance( abs( _globalX - int(event->x_root) ) + abs( _globalY - int(event->y_root) ) );
+        // check displacement with respect to drag start
+        const int distance( abs( _x - int(event->x_root) ) + abs( _y - int(event->y_root) ) );
 
-            if( distance > 0 && _timer.isRunning() ) _timer.stop();
-            if( distance < _dragDistance ) return false;
-
-        }
+        if( distance > 0 && _timer.isRunning() ) _timer.stop();
+        if( distance < _dragDistance ) return false;
 
         // start drag from current position
-        if( _useWMMoveResize )
-        {
-
-            return startDrag( widget, int(event->x_root), int(event->y_root), event->time );
-
-        } else {
-
-            if( !_dragInProgress )
-            {
-                setCursor( widget );
-                _dragInProgress = true;
-            }
-
-            GtkWindow* topLevel = GTK_WINDOW( gtk_widget_get_toplevel( widget ) );
-            int wx, wy;
-            gtk_window_get_position( topLevel, &wx, &wy );
-            gtk_window_move( topLevel, wx + event->x - _x, wy + event->y - _y );
-            return true;
-
-        }
+        return startDrag( widget, int(event->x_root), int(event->y_root) );
 
     }
 
     //_________________________________________________________________
-    bool WindowManager::startDrag( GtkWidget* widget, int x, int y, guint32 time )
+    bool WindowManager::startDrag( GtkWidget* widget, int x, int y )
     {
-
         // create xevent and send.
-        if( _useWMMoveResize )
-        {
+        XEvent     xev;
+        GtkWindow  *topLevel = GTK_WINDOW( gtk_widget_get_toplevel( widget ) );
+        GdkWindow  *window = gtk_widget_get_window( GTK_WIDGET( topLevel ) );
+        GdkDisplay *display = gtk_widget_get_display( GTK_WIDGET( topLevel ) );
+        GdkWindow  *root = gdk_screen_get_root_window( gtk_window_get_screen( topLevel ) );
 
-            _dragInProgress = true;
-            GtkWindow* topLevel = GTK_WINDOW( gtk_widget_get_toplevel( widget ) );
-            gtk_window_begin_move_drag( topLevel, Gtk::LeftButton, x, y, time );
-            resetDrag();
+        xev.xclient.type = ClientMessage;
+        xev.xclient.message_type = gdk_x11_get_xatom_by_name_for_display(display, "_NET_WM_MOVERESIZE");
+        xev.xclient.display = GDK_DISPLAY_XDISPLAY(display);
+        xev.xclient.window = GDK_WINDOW_XID(window);
+        xev.xclient.format = 32;
+        xev.xclient.data.l[0] = x;
+        xev.xclient.data.l[1] = y;
+        xev.xclient.data.l[2] = 8; // NET::Move
+        xev.xclient.data.l[3] = Button1;
+        xev.xclient.data.l[4] = 0;
+        XUngrabPointer(GDK_DISPLAY_XDISPLAY(display), CurrentTime);
 
-        } else if( !_dragInProgress ) {
+        XSendEvent(
+            GDK_DISPLAY_XDISPLAY(display),
+            GDK_WINDOW_XID(root),
+            False,
+            SubstructureRedirectMask | SubstructureNotifyMask,
+            &xev);
 
-            _dragInProgress = true;
-            setCursor( widget );
+        // force a release as some widgets miss it...
+        finishDrag();
 
-        }
+        // wmButtonRelease( widget, 0L, this );
 
         return true;
-
-    }
-
-    //_________________________________________________________________
-    void WindowManager::setCursor( GtkWidget* widget )
-    {
-
-        GdkWindow* window( gtk_widget_get_window( gtk_widget_get_toplevel( widget ) ) );
-        _oldCursor = gdk_window_get_cursor( window );
-        gdk_window_set_cursor( window, _cursor );
-    }
-
-    //_________________________________________________________________
-    void WindowManager::unsetCursor( GtkWidget* widget )
-    {
-        GdkWindow* window( gtk_widget_get_window( gtk_widget_get_toplevel( widget ) ) );
-        gdk_window_set_cursor( window, _oldCursor );
     }
 
     //_________________________________________________
-    bool WindowManager::resetDrag( void )
+    bool WindowManager::finishDrag( void )
     {
 
         _widget = 0L;
         _lastRejectedEvent = 0L;
         _x = -1;
         _y = -1;
-        _globalX = -1;
-        _globalY = -1;
-        _time = 0;
 
         // stop timer
         if( _timer.isRunning() ) _timer.stop();
 
-        if( _dragAboutToStart || _dragInProgress )
+        if( _drag )
         {
 
-            _dragAboutToStart = false;
-            _dragInProgress = false;
+            // get device manager
+            GdkDeviceManager* manager( gdk_display_get_device_manager( gdk_display_get_default() ) );
+
+            // get pointer
+            GdkDevice* pointer( gdk_device_manager_get_client_pointer( manager ) );
+
+            // ungrab
+            if( pointer ) gdk_device_ungrab( pointer, GDK_CURRENT_TIME );
+
+            _drag = false;
             return true;
 
         } else return false;
@@ -504,27 +382,23 @@ namespace Oxygen
     }
 
     //_________________________________________________
-    bool WindowManager::canDrag( GtkWidget* widget, GdkEventButton* event )
+    bool WindowManager::isWindowDragWidget( GtkWidget* widget, GdkEventButton* event )
     {
-
-        if( _dragMode == Disabled ) return false;
-        else if( !_dragAboutToStart && checkCursor( event->window ) && withinWidget(widget, event ) && useEvent( widget, event ) )
+        if( _mode == Disabled ) return false;
+        else if( (!_drag) && withinWidget(widget, event ) && useEvent( widget, event ) )
         {
 
             // store widget and event position
             _widget = widget;
-            _x = int(event->x);
-            _y = int(event->y);
-            _globalX = int(event->x_root);
-            _globalY = int(event->y_root);
-            _time = event->time;
+            _x = int(event->x_root);
+            _y = int(event->y_root);
 
             // start timer
             if( _timer.isRunning() ) _timer.stop();
             _timer.start( _dragDelay, (GSourceFunc)startDelayedDrag, this );
 
             // enable drag and accept
-            _dragAboutToStart = true;
+            _drag = true;
             return true;
 
         } else {
@@ -536,18 +410,6 @@ namespace Oxygen
 
     }
 
-    //_________________________________________________
-    bool WindowManager::checkCursor( GdkWindow* window ) const
-    {
-        if( !window ) return true;
-        GdkCursor* cursor = gdk_window_get_cursor( window );
-
-        // do not propagate if widget's cursor is currently modified,
-        // since it is usually indicative of mouse action
-        return !cursor || gdk_cursor_get_cursor_type( cursor ) == GDK_ARROW;
-
-    }
-
     //_________________________________________________
     bool WindowManager::withinWidget( GtkWidget* widget, GdkEventButton* event ) const
     {
@@ -573,30 +435,27 @@ namespace Oxygen
         wy += ny;
 
         // get widget size.
-        GtkAllocation allocation( Gtk::gtk_widget_get_allocation( widget ) );
-
-        // translate event position in 'local' coordinates with respect to widget's window
-        const int xLocal  = int(event->x_root) - wx + allocation.x;
-        const int yLocal  = int(event->y_root) - wy + allocation.y;
-
+        // for notebooks, only consider the tabbar rect
+        GtkAllocation allocation;
         if( GTK_IS_NOTEBOOK( widget ) )
         {
 
-            GtkAllocation tabbarRect;
-            Gtk::gtk_notebook_get_tabbar_rect( GTK_NOTEBOOK( widget ), &tabbarRect );
-
-            // compare to event local position
-            if( !Gtk::gdk_rectangle_contains( &tabbarRect, xLocal, yLocal ) ) return false;
-            else if( !Style::instance().animations().tabWidgetEngine().contains( widget ) ) return false;
-            else return !Style::instance().animations().tabWidgetEngine().isInTab( widget, xLocal, yLocal );
+            const GtkAllocation local( Gtk::gtk_widget_get_allocation( widget ) );
+            Gtk::gtk_notebook_get_tabbar_rect( GTK_NOTEBOOK( widget ), &allocation );
+            allocation.x += wx - local.x;
+            allocation.y += wy - local.y;
 
         } else {
 
-            // compare to event position
-            return Gtk::gdk_rectangle_contains( &allocation, xLocal, yLocal );
+            allocation = Gtk::gtk_widget_get_allocation( widget );
+            allocation.x = wx;
+            allocation.y = wy;
 
         }
 
+        // compare to event root position
+        return Gtk::gdk_rectangle_contains( &allocation, int(event->x_root), int(event->y_root) );
+
     }
 
     //_________________________________________________
@@ -604,8 +463,8 @@ namespace Oxygen
     {
 
         // check against mode
-        if( _dragMode == Disabled ) return false;
-        if( _dragMode == Minimal && !( GTK_IS_TOOLBAR( widget ) || GTK_IS_MENU_BAR( widget ) ) ) return false;
+        if( _mode == Disabled ) return false;
+        if( _mode == Minimal && !( GTK_IS_TOOLBAR( widget ) || GTK_IS_MENU_BAR( widget ) ) ) return false;
         if( _lastRejectedEvent && event == _lastRejectedEvent ) return false;
 
         // always accept if widget is not a container
@@ -677,13 +536,13 @@ namespace Oxygen
             { continue; }
 
             // check special cases for which grab should not be enabled
-            if( usable && (
-                widgetIsBlackListed( childWidget ) ||
+            if(
+                ( widgetIsBlackListed( childWidget ) ) ||
                 ( GTK_IS_NOTEBOOK( widget ) && Gtk::gtk_notebook_is_tab_label( GTK_NOTEBOOK( widget ), childWidget ) ) ||
                 ( GTK_IS_BUTTON( childWidget ) && gtk_widget_get_state( childWidget ) != GTK_STATE_INSENSITIVE ) ||
                 ( gtk_widget_get_events ( childWidget ) & (GDK_BUTTON_PRESS_MASK|GDK_BUTTON_RELEASE_MASK) ) ||
                 ( GTK_IS_MENU_ITEM( childWidget ) ) ||
-                ( GTK_IS_SCROLLED_WINDOW( childWidget ) && ( !inNoteBook || gtk_widget_is_focus( childWidget ) ) ) ) )
+                ( GTK_IS_SCROLLED_WINDOW( childWidget ) && ( !inNoteBook || gtk_widget_is_focus( childWidget ) ) ) )
             { usable = false; }
 
             // if child is a container and event has been accepted so far, also check it, recursively
@@ -708,21 +567,6 @@ namespace Oxygen
         return usable;
     }
 
-    //_________________________________________________
-    bool WindowManager::widgetHasBlackListedParent( GtkWidget* widget ) const
-    {
-
-        #if OXYGEN_DEBUG
-        std::cerr << "Oxygen::WindowManager::widgetHasBlackListedParent - " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")" << std::endl;
-        #endif
-
-        // loop over widget parent
-        for( GtkWidget* parent = gtk_widget_get_parent( widget ); parent; parent = gtk_widget_get_parent( parent ) )
-        { if( _blackListWidgets.find( parent ) != _blackListWidgets.end() ) return true; }
-
-        return false;
-    }
-
     //_________________________________________________
     void WindowManager::initializeBlackList( void )
     {
@@ -736,7 +580,6 @@ namespace Oxygen
         _blackList.push_back( "MetaFrames" );
         _blackList.push_back( "SPHRuler" );
         _blackList.push_back( "SPVRuler" );
-        _blackList.push_back( "GtkPlug" );
     }
 
     //________________________________________________________________________________
