@@ -7,7 +7,7 @@
 * -------------------
 *
 * Copyright (c) 2010 Cédric Bellegarde <gnumdk@gmail.com>
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
 *
 * Largely inspired from Qtcurve style
 * Copyright (C) Craig Drummond, 2003 - 2010 craig.p.drummond@gmail.com
@@ -57,14 +57,6 @@ namespace Oxygen
         //! initialize hooks
         void initializeHooks( void );
 
-        //! returns true if window manager is used for moving
-        bool useWMMoveResize( void ) const
-        { return _useWMMoveResize; }
-
-        //! use window manager for moving, when available
-        void setUseWMMoveResize( bool value )
-        { _useWMMoveResize = value; }
-
         //! window grab mode
         enum Mode
         {
@@ -74,7 +66,7 @@ namespace Oxygen
         };
 
         //! window grab mode
-        void setDragMode( Mode mode );
+        void setMode( Mode mode );
 
         //! drag distance
         void setDragDistance( int value )
@@ -101,13 +93,10 @@ namespace Oxygen
         //! on window destroy
         static gboolean wmDestroy( GtkWidget*, gpointer );
 
-        //! on window destroy
-        static gboolean wmBlackListDestroy(  GtkWidget*, gpointer );
-
         //! delayed drag
         static gboolean startDelayedDrag( gpointer );
 
-        //! style-set hook
+        //! style-updated hook
         static gboolean styleSetHook( GSignalInvocationHint*, guint, const GValue*, gpointer );
 
         //! mouse button release event hook
@@ -117,41 +106,26 @@ namespace Oxygen
 
         //! register widget
         /*! returns true if widget is effictively registered */
-        bool registerWidget( GtkWidget* );
+        virtual bool registerWidget( GtkWidget* );
 
         //! unregister widget
-        void unregisterWidget( GtkWidget* );
-
-        //! register blacklist widget
-        bool registerBlackListWidget( GtkWidget* );
-
-        //! unregister blacklist widget
-        void unregisterBlackListWidget( GtkWidget* );
+        virtual void unregisterWidget( GtkWidget* );
 
         //! start dragging widget
         bool startDrag( GtkWidget*, GdkEventMotion* );
 
         //! start dragging widget
-        bool startDrag( GtkWidget*, int, int, guint32 );
+        bool startDrag( GtkWidget*, int, int );
 
         //! start dragging widget
         void startDrag( void )
-        { if( _dragAboutToStart && _widget ) startDrag( _widget, _globalX, _globalY, _time ); }
-
-        //! set cursor
-        void setCursor( GtkWidget* );
-
-        //! unset cursor
-        void unsetCursor( GtkWidget* );
+        { if( _drag && _widget ) startDrag( _widget, _x, _y ); }
 
         //! finish dragging widget
-        bool resetDrag( void );
+        bool finishDrag( void );
 
         //! return true if window is dragable
-        bool canDrag( GtkWidget*, GdkEventButton* );
-
-        //! check cursor
-        bool checkCursor( GdkWindow* ) const;
+        bool isWindowDragWidget( GtkWidget*, GdkEventButton* );
 
         //! return true if event happen in widget
         bool withinWidget( GtkWidget*, GdkEventButton* ) const;
@@ -192,9 +166,6 @@ namespace Oxygen
         bool widgetIsBlackListed( GtkWidget* widget ) const
         { return std::find_if( _blackList.begin(), _blackList.end(), BlackListFTor( G_OBJECT( widget ) ) ) != _blackList.end(); }
 
-        //! return true if widget has a black listed parent
-        bool widgetHasBlackListedParent( GtkWidget* widget ) const;
-
         //! stores connections
         class Data
         {
@@ -231,16 +202,8 @@ namespace Oxygen
 
         private:
 
-        //! use WM moveResize
-        bool _useWMMoveResize;
-
-        //! cursor
-        bool _cursorLoaded;
-        GdkCursor* _cursor;
-        GdkCursor* _oldCursor;
-
         //! drag mode
-        Mode _dragMode;
+        Mode _mode;
 
         //! true when hooks are initialized
         bool _hooksInitialized;
@@ -254,11 +217,8 @@ namespace Oxygen
         //! timer
         Timer _timer;
 
-        //! true if in drag can start
-        bool _dragAboutToStart;
-
-        //! true if dragging
-        bool _dragInProgress;
+        //! true if in drag mode
+        bool _drag;
 
         //! drag distance
         int _dragDistance;
@@ -277,20 +237,9 @@ namespace Oxygen
         int _x;
         int _y;
 
-        //! drag position
-        int _globalX;
-        int _globalY;
-
-        //! drag time
-        guint32 _time;
-
-        //! widget typenames black-list
+        //! widget black list
         std::vector<std::string> _blackList;
 
-        //! widget black-list
-        typedef std::map< GtkWidget*, Signal > WidgetMap;
-        WidgetMap _blackListWidgets;
-
         //! map widgets to data structure
         DataMap<Data> _map;
 
